Search (psychologist a paradox ) | nitter

Filter
Retweets Media Videos News Verified Native videos Replies Links Images Safe Quotes Pro videos
Exclude
Retweets Media Videos News Verified Native videos Replies Links Images Safe Quotes Pro videos
Time range
-
Near

- Tweets
- Users

Blahblalala @blahlaja
1h
@elonmusk is an A.I. psychologist a paradox or conundrum. If I'm moronic... I'd call myself oxymoron ijs.. @ShytoshiKusama @marciejastrow @jackhstorms @jds_updates @JeffBezos @badideaai @cz_binance @CoachGeorgeCRA @
Lawrence @AllowingAnxiety
Jul 16
Replying to @RDelaney
This reminds me of a quote by Carl Rogers (Humanistic Psychologist). "The curious paradox is that when I accept myself just as I am, then I change". As you say, it's a hard practice But so worth it!
2
SGaut retweeted
Rob Lewis (@🏠 🙏🇺🇦) @GRobLewis
Jul 15
Replying to @sgaut @HuffPostPol
Conservatives’ dirty little secret is that one of their most cherished doctrines—more choice is *always* better—is false. Psychologist Barry Schwartz did a great book and TED Talk on “The Paradox of Choice”.
1
1
Wish to Nourish retweeted
The New Yorker @NewYorker
Jul 12
It’s tempting to see the flow of information as one-way, from the mind to the body, but it may make more sense to think of the body and mind as part of a single “prediction system,” a psychologist said. nyer.cm/a7TITNj

## The Paradox of Listening to Our Bodies

Interoception—the inner sense linking our bodies and minds—can confuse as much as it can reveal.

newyorker.com
8
30
Javier Noguera retweeted
The New Yorker @NewYorker
Jul 7
It’s tempting to see the flow of information as one-way, from the mind to the body, but it may make more sense to think of the body and mind as part of a single “prediction system,” a psychologist said. nyer.cm/NTvYvoE

## The Paradox of Listening to Our Bodies

Interoception—the inner sense linking our bodies and minds—can confuse as much as it can reveal.

newyorker.com
7
32
Load more